<?php
//Block direct access to the file
if ( !function_exists( 'add_action' ) ) {
	exit; 
}

require_once( 'vulnerabilities-table-class.php' );

//Load vulnerabilities
$plugin_vulnerabilities = array();
include_once('vulnerabilities.php');

//Check if installed plugins have vulnerabilities
$plugin_list = get_plugins();
$plugin_list_paths = array_keys($plugin_list);
$current_vulnerabilities = array();
$old_vulnerabilities = array();
foreach ($plugin_list_paths as &$value) {
	preg_match_all('/([a-z0-9\-]+)\//', $value, $plugin_path);
	if (isset($plugin_path[1][0])) {
		$plugin_path=$plugin_path[1][0];

		if (array_key_exists($plugin_path, $plugin_vulnerabilities)) {
			$plugin = get_plugin_data( WP_PLUGIN_DIR."/".$value, $markup = true, $translate = true );
			foreach ($plugin_vulnerabilities[$plugin_path] as &$vulnerability) {
				if ( version_compare( $plugin["Version"], $vulnerability["FirstVersion"], '>=') && version_compare( $plugin["Version"], $vulnerability["LastVersion"], '<=') ) {
					$current_vulnerabilities[] = array(
						'name' => '<a href="'.get_admin_url().'plugin-install.php?tab=plugin-information&#038;plugin='.$plugin_path.'&#038;TB_iframe=true&#038;width=600&#038;height=550" class="thickbox open-plugin-details-modal">'.$plugin["Name"].'</a>',
						'versions' => $vulnerability["FirstVersion"].'-'.$vulnerability["LastVersion"],
						'type' => ucwords( $vulnerability["TypeOfVulnerability"] ),
						'details' => '<a href="'.$vulnerability["URL"].'" target="_blank">View Details</a>'
					);
				}
				else
					$old_vulnerabilities[] = array(
						'name' => '<a href="'.get_admin_url().'plugin-install.php?tab=plugin-information&#038;plugin='.$plugin_path.'&#038;TB_iframe=true&#038;width=600&#038;height=550" class="thickbox open-plugin-details-modal">'.$plugin["Name"].'</a>',
						'versions' => $vulnerability["FirstVersion"].'-'.$vulnerability["LastVersion"],
						'type' => ucwords( $vulnerability["TypeOfVulnerability"] ),
						'details' => '<a href="'.$vulnerability["URL"].'" target="_blank">View Details</a>'
					);
			}
		}
	}
}

?>

<div class="wrap">
<h2><?php _e('Plugin Vulnerabilities', 'plugin-vulnerabilities' );?></h2>
<br />
<h3><?php _e('Results for plugins we have seen hackers attempting to exploit:', 'plugin-vulnerabilities' );?></h3>
<br />
<?php if ( !empty($current_vulnerabilities)  ) {
		echo "<h4><b>".__('Installed plugins that have known vulnerabilities in the installed version of the plugin:', 'plugin-vulnerabilities')."</b></h3>";
		$current_vulnerabilities_table = new Vulnerabilities_Table();
		$current_vulnerabilities_table->add_data($current_vulnerabilities);
		$current_vulnerabilities_table->prepare_items();
		$current_vulnerabilities_table->display();
	}
	else 
		echo "<h4><b>".__('No installed plugins have known vulnerabilities in the installed versions.', 'plugin-vulnerabilities')."</b></h3><br />";
	if ( !empty($old_vulnerabilities) ) {
		echo "<h4><b>".__('Installed plugins that have known vulnerabilities in other versions of the plugin:', 'plugin-vulnerabilities')."</b></h3>";
		$old_vulnerabilities_table = new Vulnerabilities_Table();
		$old_vulnerabilities_table->add_data( $old_vulnerabilities );
		$old_vulnerabilities_table->prepare_items();
		$old_vulnerabilities_table->display();
	}
	else 
		echo "<h4><b>".__('No installed plugins have known vulnerabilities in other versions.', 'plugin-vulnerabilities')."</b></h3>";
?>

<br><br>
<hr>
<p><?php _e('You can get alerted for known vulnerabilities in all the plugins you use, not just ones that we have seen evidence that hackers are targeting, when you sign up for our <a href="https://www.pluginvulnerabilities.com/" target="_blank">Plugin Vulnerabilites service</a>. You can see what you are missing out on by not already having signed up by checking out our recent <a href="https://www.pluginvulnerabilities.com/category/weekly-updates/" target="_blank">weekly update posts</a> detailing new additions to our data set.', 'plugin-vulnerabilities' );?></p>
<p><?php _e('If your website has been hacked, you can get a free lifetime subscription to the service when you use our <a href="https://www.whitefirdesign.com/services/hacked-wordpress-website-cleanup.html" target="_blank">professional hack cleanup service for WordPress</a> to get your website cleaned up.', 'plugin-vulnerabilities' );?></p>
<p><?php _e("Once you have <a href='https://www.pluginvulnerabilities.com/product/subscription/'>signed up</a>, please enter your account's API details below:", 'plugin-vulnerabilities' );?></p>
<form  action="plugins.php?page=plugin-vulnerabilities" method="post">
<table class="form-table">
<tr valign="top">
<th scope="row"><label for="api-license-key"><?php _e('API License Key:', 'plugin-vulnerabilities' );?></label></th>
<td><fieldset>
<input name="api-license-key" value="<?php if ( isset ( $_POST['api-license-key'] ) )
										   		echo esc_attr($_POST['api-license-key']); ?>">
</fieldset></td>
</tr>
<tr valign="top">
<th scope="row"><label for="api-license-email"><?php _e('API License Email:', 'plugin-vulnerabilities' );?></label></th>
<td><fieldset>
<input name="api-license-email" value="<?php if ( isset ( $_POST['api-license-email'] ) )
												echo esc_attr($_POST['api-license-email']); ?>">
</fieldset></td>
</tr>
</table>
<?php if ( isset ($activation_error ) ): ?>
	<span style="color:red">
	<?php  _e('Could not activate API license key.', 'plugin-vulnerabilities' );?>
	<br>
	<?php  echo __('Error Given', 'plugin-vulnerabilities').': '.$activation_error; ?>
	</span>
<?php endif; ?>
<?php wp_nonce_field('plugin_vulnerabilities','plugin_vulnerabilities'); ?>
<p class="submit"><input type="submit" name="submit" id="submit" class="button button-primary" value="<?php _e('Activate API License Key', 'plugin-vulnerabilities' );?>"  /></p>
</form>